# trimesh/resources/schemas

Contains [JSON schema](https://json-schema.org/) for exports. The goal is if there is a JSON export format (like the header of a GLTF file) or a `to_dict` method to have a well-defined schema we can validate in unit tests. 